@@ -1,4 +1,4 @@
-/* Copyright 2013 Akira Ohta (akohta001@gmail.com)
+/* Copyright 2013,2014 Akira Ohta (akohta001@gmail.com)
     This file is part of ntch.
 
     The ntch is free software: you can redistribute it and/or modify
@@ -49,6 +49,7 @@ int NT_PTHREAD_POOL_SIZE;
 int NT_PTHREAD_POOL_QUEUE_SIZE;
 int NT_AUTO_SCROLL_INTERVAL;
 int NT_AUTO_UPDATE_INTERVAL;
+int APP_MODE;
 
 char *RFC2898_SALT;
 int  RFC2898_ITERATION;
@@ -73,6 +74,7 @@ struct option longopts[] = {
 	{"editor", 1, NULL, 'e'},
 	{"out-path", 1, NULL, 'o'},
 	{"pem", 1, NULL, 'p'},
+	{"server", 2, NULL, 's'},
 	{NULL, 0, NULL, 0}
 };
 
@@ -96,6 +98,8 @@ int set_option(int argc, char* argv[])
 	uid_t uid;
 	struct passwd *pw;
 	char buf[256];
+	
+	APP_MODE = NT_APP_MODE_CLIENT;
 
 	MARU_ID = NULL;
 	MARU_PW = NULL;
@@ -142,7 +146,7 @@ int set_option(int argc, char* argv[])
 	}
 
 	while((opt = getopt_long(
-			argc, argv, "hvro:p:", longopts, NULL)) != -1){
+			argc, argv, "hvro:p:s::", longopts, NULL)) != -1){
 
 		switch(opt){
 		case 'r':
@@ -174,6 +178,9 @@ int set_option(int argc, char* argv[])
 				break;
 			strcpy(CA_FILE_PATH, optarg);
 			break;
+		case 's':
+			APP_MODE = NT_APP_MODE_SERVER;
+			break;
 		default:
 			break;
 		}
@@ -246,6 +253,8 @@ extern BOOL read_resource(const char *path)
 				break;
 			if(0 == strcmp(init_disp, "favorite")){
 				INIT_DISP_STATE = NT_INTI_DISP_FAVORITE;
+			}else if(0 == strcmp(init_disp, "history")){
+				INIT_DISP_STATE = NT_INTI_DISP_HISTORY;
 			}
 			free(init_disp);
 			continue;
