@@ -1,4 +1,4 @@
-/* Copyright 2013 Akira Ohta (akohta001@gmail.com)
+/* Copyright 2013,2014 Akira Ohta (akohta001@gmail.com)
     This file is part of ntch.
 
     The ntch is free software: you can redistribute it and/or modify
@@ -44,16 +44,23 @@ extern int NT_PTHREAD_POOL_QUEUE_SIZE;
 extern int NT_AUTO_UPDATE_INTERVAL;
 extern int NT_AUTO_SCROLL_INTERVAL;
 
+extern int APP_MODE;
+
+
 extern char EDITOR_CMD[]; 
 extern char *MARU_ID;
 extern char *MARU_PW;
 
+#define NT_APP_MODE_SERVER 1
+#define NT_APP_MODE_CLIENT 2
+
 #define NT_THREAD_SORT_BY_NUMBER 1
 #define NT_THREAD_SORT_BY_UNREAD 2
 #define NT_THREAD_SORT_BY_READ 3
 
 #define NT_INTI_DISP_BOARDMENU 1
 #define NT_INTI_DISP_FAVORITE  2
+#define NT_INTI_DISP_HISTORY   3
 
 #define NT_KEY_NONE (-1)
 #define NT_KEY_UP 'k'
@@ -99,6 +106,8 @@ extern char *MARU_PW;
 #define NT_COMMAND1_SEARCH_2 "se"
 #define NT_COMMAND1_FAVORITE_1 "favorite"
 #define NT_COMMAND1_FAVORITE_2 "f"
+#define NT_COMMAND1_HISTORY_1 "history"
+#define NT_COMMAND1_HISTORY_2 "h"
 #define NT_COMMAND1_AUTOSCROLL_1 "autoscroll"
 #define NT_COMMAND1_AUTOSCROLL_2 "a"
 #define NT_COMMAND1_UPLOAD_1 "upload"
@@ -106,6 +115,8 @@ extern char *MARU_PW;
 #define NT_COMMAND1_UPLOAD_BOARD2 "b"
 #define NT_COMMAND1_UPLOAD_THREAD1 "thread"
 #define NT_COMMAND1_UPLOAD_THREAD2 "t"
+#define NT_COMMAND1_LIMIT_1 "limit"
+#define NT_COMMAND1_LIMIT_2 "l"
 
 extern int set_option(int argc, char* argv[]);
 
