@@ -44,21 +44,23 @@
 #define	DISP_STATE_RESLIST			3
 #define	DISP_STATE_EDITOR			4 
 #define	DISP_STATE_HTML_RESULT		5
-#define	DISP_STATE_REFRESH			6
-#define	DISP_STATE_SEARCH_THREAD	7
-#define	DISP_STATE_FAVORITE			8
+#define	DISP_STATE_SEARCH_THREAD	6
+#define	DISP_STATE_FAVORITE			7
+#define	DISP_STATE_HISTORY			8
 
 #define DISP_CMD_ADD_FAVORITE (1*256)
 #define DISP_CMD_DEL_FAVORITE_BOARD (2*256)
 #define DISP_CMD_DEL_FAVORITE_GRP (3*256)
 #define DISP_CMD_DEL_FAVORITE_THREAD (4*256)
-#define DISP_CMD_SEL_FAVORITE_BOARD (5*256)
-#define DISP_CMD_SEL_FAVORITE_THREAD (6*256)
+#define DISP_CMD_SEL_BOARD (5*256)
+#define DISP_CMD_SEL_THREAD (6*256)
 #define DISP_CMD_UPDATE_FAVORITE (7*256)
 #define DISP_CMD_AUTO_SCROLL (8*256)
 #define DISP_CMD_UPLOAD_ALL (9*256)
 #define DISP_CMD_UPLOAD_BOARDS (10*256)
 #define DISP_CMD_UPLOAD_THREADS (11*256)
+#define DISP_CMD_REFRESH (12*256)
+#define DISP_CMD_REENTER (13*256)
 
 extern int disp_board_menu(nt_window_tp wp, 
 		nt_2ch_model_handle h_model, nt_2ch_selected_item_handle h_select);
@@ -73,12 +75,18 @@ extern int disp_favorite(nt_window_tp wp, int prev_state,
 		nt_2ch_model_handle h_model, nt_favorite_handle h_favorite, 
 		nt_usr_db_handle h_usr_db,
 		void **result_hadle, nt_searched_thread_handle *h_sel_threadp);
+extern int disp_history(nt_window_tp wp, int prev_state, 
+		nt_2ch_model_handle h_model, 
+		nt_usr_db_handle h_usr_db,
+		nt_searched_thread_handle *h_sel_threadp,
+		nt_link_tp *update_board_list);
 extern void free_board_menu_ctx(void *ptr);
 extern void init_threadlist_ctx(void *ptr);
 extern void free_threadlist_ctx(void *ptr);
 extern void free_reslist_ctx(void *ptr);
 extern void free_search_thread_ctx(void *ptr);
 extern void free_favorite_ctx(void *ptr);
+extern void free_history_ctx(void *ptr);
 extern BOOL disp_editor(nt_write_data_handle h_write_data);
 extern int disp_html_result(nt_write_data_handle h_write_data);
 
