@@ -1,4 +1,4 @@
-/* Copyright 2013 Akira Ohta (akohta001@gmail.com)
+/* Copyright 2013,2014 Akira Ohta (akohta001@gmail.com)
     This file is part of ntch.
 
     The ntch is free software: you can redistribute it and/or modify
@@ -52,6 +52,8 @@
 #endif
 #define S_SIZE 	(1024)
 
+extern int server_main();
+
 static int draw_title(WINDOW *wp, const wchar_t *title, attr_t attr);
 #ifdef NT_CLOUD
 static BOOL DoLoop(WINDOW *scrp, nt_usr_db_handle db_handle,
@@ -92,6 +94,10 @@ int main(int argc, char *argv[])
 	if(0 != set_option(argc, argv)){
 		return 1;
 	}
+	
+	if(APP_MODE == NT_APP_MODE_SERVER){
+		return server_main();
+	}
 
 	sleep(1);
 
@@ -279,6 +285,7 @@ static BOOL DoLoop(WINDOW *scrp, nt_usr_db_handle db_handle,
 	nt_window_tp rwinp = NULL;
 	nt_window_tp search_winp = NULL;
 	nt_window_tp favorite_winp = NULL;
+	nt_window_tp history_winp = NULL;
 	char buf[256];
 	wchar_t title_buf[128];
 	wchar_t wch;
@@ -305,6 +312,8 @@ static BOOL DoLoop(WINDOW *scrp, nt_usr_db_handle db_handle,
 	state = DISP_STATE_BOARDMENU;
 	if(INIT_DISP_STATE == NT_INTI_DISP_FAVORITE){
 		disp_state = DISP_STATE_FAVORITE; 
+	}else if(INIT_DISP_STATE == NT_INTI_DISP_HISTORY){
+		disp_state = DISP_STATE_HISTORY; 
 	}else{
 		disp_state = DISP_STATE_BOARDMENU; 
 	}
@@ -390,14 +399,9 @@ static BOOL DoLoop(WINDOW *scrp, nt_usr_db_handle db_handle,
 				}else{
 					print_error(scrp, NT_ERR_MSG_COUDLNOT_READ_BOARD);
 				}
-			}else if(state == DISP_STATE_SEARCH_THREAD){
+			}else if(state != DISP_STATE_BOARDMENU){
+				disp_state = state;
 				state = DISP_STATE_BOARDMENU;
-				disp_state = DISP_STATE_SEARCH_THREAD;
-				ch = NT_KEY_NONE;
-				continue;
-			}else if(DISP_STATE_FAVORITE == state){
-				state = DISP_STATE_BOARDMENU;
-				disp_state = DISP_STATE_FAVORITE;
 				ch = NT_KEY_NONE;
 				continue;
 			}
@@ -433,6 +437,20 @@ static BOOL DoLoop(WINDOW *scrp, nt_usr_db_handle db_handle,
 					}else{
 						status_msg = NT_ERR_MSG_ADD_FAVORITE_FAILED;
 					}
+				}else if(DISP_CMD(state) == DISP_CMD_REFRESH){
+					if(nt_read_board(h_sel_items)){
+						if(twinp->data){
+							free_threadlist_ctx(twinp->data);
+							twinp->data = NULL;
+						}
+						ch = NT_KEY_NONE;
+						status_msg = NT_INFO_REFRESH_BOARD_SUCCESS;
+						state = DISP_STATE_THREADTITLE;
+						disp_state = state;
+						continue;
+					}else{
+						status_msg = NT_ERR_MSG_COUDLNOT_READ_BOARD;
+					}
 				}
 				state = DISP_STATE_THREADTITLE;
 				ch = NT_KEY_NONE;
@@ -442,21 +460,6 @@ static BOOL DoLoop(WINDOW *scrp, nt_usr_db_handle db_handle,
 					disp_state = state;
 					ch = NT_KEY_NONE;
 					continue;
-			}else if(DISP_STATE_REFRESH == state){
-				if(nt_read_board(h_sel_items)){
-					if(twinp->data){
-						free_threadlist_ctx(twinp->data);
-						twinp->data = NULL;
-					}
-					ch = NT_KEY_NONE;
-					status_msg = NT_INFO_REFRESH_BOARD_SUCCESS;
-					state = DISP_STATE_THREADTITLE;
-					disp_state = state;
-					continue;
-				}else{
-					status_msg = NT_ERR_MSG_COUDLNOT_READ_BOARD;
-				}
-				state = DISP_STATE_THREADTITLE;
 			}else if(DISP_STATE_RESLIST == state){
 				disp_state = state;
 				if(!nt_read_thread(h_sel_items)){
@@ -478,14 +481,9 @@ static BOOL DoLoop(WINDOW *scrp, nt_usr_db_handle db_handle,
 				state = DISP_STATE_THREADTITLE;
 				ch = NT_KEY_NONE;
 				continue;
-			}else if(DISP_STATE_SEARCH_THREAD == state){
+			}else if(DISP_STATE_THREADTITLE != state){
+				disp_state = state;
 				state = DISP_STATE_THREADTITLE;
-				disp_state = DISP_STATE_SEARCH_THREAD;
-				ch = NT_KEY_NONE;
-				continue;
-			}else if(DISP_STATE_FAVORITE == state){
-				state = DISP_STATE_THREADTITLE;
-				disp_state = DISP_STATE_FAVORITE;
 				ch = NT_KEY_NONE;
 				continue;
 			}else{
@@ -518,6 +516,21 @@ static BOOL DoLoop(WINDOW *scrp, nt_usr_db_handle db_handle,
 							h_timer_auto_scroll, NT_AUTO_SCROLL_INTERVAL);
 					}
 					auto_scrolling = TRUE;
+				}else if(DISP_CMD(state) == DISP_CMD_REFRESH){
+					state = DISP_STATE_RESLIST;
+					ch = NT_KEY_NONE;
+					if(!nt_read_thread(h_sel_items)){
+						status_msg = NT_ERR_MSG_REFRESH_THREAD_FAILED;
+						wclear(scrp);
+						continue;
+					}
+					if(rwinp->data){
+						free_reslist_ctx(rwinp->data);
+						rwinp->data = NULL;
+					}
+					status_msg = NT_INFO_REFRESH_THREAD_SUCCESS;
+					wclear(scrp);
+					continue;
 				}
 				DISP_CLR_CMD(state);
 			}
@@ -526,33 +539,9 @@ static BOOL DoLoop(WINDOW *scrp, nt_usr_db_handle db_handle,
 			}
 			if(DISP_STATE_ERROR == state){
 				goto END_WHILE;
-			}else if(state == DISP_STATE_REFRESH){
-				state = DISP_STATE_RESLIST;
-				ch = NT_KEY_NONE;
-				if(!nt_read_thread(h_sel_items)){
-					status_msg = NT_ERR_MSG_REFRESH_THREAD_FAILED;
-					wclear(scrp);
-					continue;
-				}
-				if(rwinp->data){
-					free_reslist_ctx(rwinp->data);
-					rwinp->data = NULL;
-				}
-				status_msg = NT_INFO_REFRESH_THREAD_SUCCESS;
-				wclear(scrp);
-				continue;
-			}else if(state == DISP_STATE_SEARCH_THREAD){
-				state = DISP_STATE_RESLIST;
-				disp_state = DISP_STATE_SEARCH_THREAD;
-				ch = NT_KEY_NONE;
-				continue;
-			}else if(DISP_STATE_FAVORITE == state){
-				state = DISP_STATE_RESLIST;
-				disp_state = DISP_STATE_FAVORITE;
-				ch = NT_KEY_NONE;
-				continue;
 			}else if(state != DISP_STATE_RESLIST){
 				disp_state = state;
+				state = DISP_STATE_RESLIST;
 				ch = NT_KEY_NONE;
 				continue;
 			}
@@ -654,6 +643,62 @@ static BOOL DoLoop(WINDOW *scrp, nt_usr_db_handle db_handle,
 				continue;
 			}
 			break;
+		case DISP_STATE_HISTORY:
+			draw_title(scrp, L"履歴", WA_REVERSE);
+			if(!history_winp)
+				history_winp = nt_disp_win_alloc(
+						scrp, LINES-1, COLS, 1, 0, buf);
+			if(!history_winp)
+				goto END_WHILE;
+			history_winp->key = ch;
+			h_searched_thread = NULL;
+			state = disp_history(history_winp, state, app_2ch_model,
+							db_handle, &h_searched_thread, &linkp);
+			if(linkp){
+				nt_read_board_list(linkp);
+				nt_all_link_free(linkp, _2ch_selected_item_free);
+			}
+			if(DISP_CMD(state)){
+				ch = NT_KEY_NONE;
+				if(DISP_CMD(state) == DISP_CMD_SEL_THREAD){
+					assert(h_searched_thread);
+					if(nt_set_sel_item(app_2ch_model,
+							&h_sel_items_tmp, h_searched_thread, &status_msg)){
+						nt_2ch_selected_item_release_ref(h_sel_items);
+						h_sel_items = h_sel_items_tmp;
+						if(rwinp->data){
+							free_reslist_ctx(rwinp->data);
+							rwinp->data = NULL;
+						}
+						if(twinp->data){
+							free_threadlist_ctx(twinp->data);
+							twinp->data = NULL;
+						}
+					}
+					nt_searched_thread_release_ref(h_searched_thread);
+					h_searched_thread = NULL;
+					disp_state = DISP_STATE_RESLIST;
+					state = DISP_STATE_HISTORY;
+					DISP_CLR_CMD(state);
+					continue;
+				}else if(DISP_CMD(state) == DISP_CMD_REENTER){
+					DISP_CLR_CMD(state);
+					continue;
+				}else if(DISP_CMD(state) == DISP_CMD_REFRESH){
+					DISP_CLR_CMD(state);
+					if(history_winp->data){
+						free_history_ctx(history_winp->data);
+						history_winp->data = NULL;
+					}
+					continue;
+				}
+			}
+			if(state != DISP_STATE_HISTORY){
+				disp_state = state;
+				ch = NT_KEY_NONE;
+				continue;
+			}
+			break;
 		case DISP_STATE_FAVORITE:
 			draw_title(scrp, L"お気に入り", WA_REVERSE);
 			if(!favorite_winp)
@@ -710,12 +755,12 @@ static BOOL DoLoop(WINDOW *scrp, nt_usr_db_handle db_handle,
 					}else{
 						status_msg = NT_ERR_MSG_DEL_FAVORITE_FAILED;
 					}
-				}else if(DISP_CMD(state) == DISP_CMD_SEL_FAVORITE_BOARD ||
-						DISP_CMD(state) == DISP_CMD_SEL_FAVORITE_THREAD){
+				}else if(DISP_CMD(state) == DISP_CMD_SEL_BOARD ||
+						DISP_CMD(state) == DISP_CMD_SEL_THREAD){
 					assert(h_searched_thread);
 					if(nt_set_sel_item(app_2ch_model,
 							&h_sel_items_tmp, h_searched_thread, &status_msg)){
-						disp_state = (DISP_CMD(state) == DISP_CMD_SEL_FAVORITE_BOARD)
+						disp_state = (DISP_CMD(state) == DISP_CMD_SEL_BOARD)
 							? DISP_STATE_THREADTITLE : DISP_STATE_RESLIST;
 						state = DISP_STATE_FAVORITE;
 						nt_2ch_selected_item_release_ref(h_sel_items);
@@ -731,6 +776,16 @@ static BOOL DoLoop(WINDOW *scrp, nt_usr_db_handle db_handle,
 					}
 					nt_searched_thread_release_ref(h_searched_thread);
 					h_searched_thread = NULL;
+				}else if(DISP_CMD(state) == DISP_CMD_REFRESH){
+					state = DISP_STATE_FAVORITE;
+					ch = NT_KEY_NONE;
+					if(favorite_winp->data){
+						free_favorite_ctx(favorite_winp->data);
+						favorite_winp->data = NULL;
+					}
+					status_msg = NT_INFO_REFRESH_FAVORITE_SUCCESS;
+					wclear(scrp);
+					continue;
 #ifdef NT_CLOUD
 				}else if(h_cloud){
 					if(DISP_CMD(state) == DISP_CMD_UPLOAD_ALL ||
@@ -764,19 +819,10 @@ static BOOL DoLoop(WINDOW *scrp, nt_usr_db_handle db_handle,
 					disp_state = state = DISP_STATE_FAVORITE;
 				}
 				continue;
-			}else if(state == DISP_STATE_REFRESH){
-				state = DISP_STATE_FAVORITE;
-				ch = NT_KEY_NONE;
-				if(favorite_winp->data){
-					free_favorite_ctx(favorite_winp->data);
-					favorite_winp->data = NULL;
-				}
-				status_msg = NT_INFO_REFRESH_FAVORITE_SUCCESS;
-				wclear(scrp);
-				continue;
 			}else if(state != DISP_STATE_FAVORITE){
 				ch = NT_KEY_NONE;
 				disp_state = state;
+				state = DISP_STATE_FAVORITE;
 				continue;
 			}else{
 				disp_state = DISP_STATE_FAVORITE;
@@ -895,6 +941,11 @@ END_WHILE:
 	free_board_menu_ctx(bwinp->data);
 	free_threadlist_ctx(twinp->data);
 	free_reslist_ctx(rwinp->data);
+	if(history_winp){
+		if(history_winp->data)
+			free_history_ctx(history_winp->data);
+		nt_disp_win_free(history_winp);
+	}
 	if(search_winp){
 		if(search_winp->data)
 			free_search_thread_ctx(search_winp->data);
