@@ -36,7 +36,7 @@
 #define NT_CMD_UPLOAD_ALL 1
 #define NT_CMD_UPLOAD_BOARDS 2
 #define NT_CMD_UPLOAD_THREADS 3
-
+#define NT_CMD_DISP_HISTORY 4
 
 typedef struct tag_favorite_ctx_t *favorite_ctx_tp;
 typedef struct tag_favorite_ctx_t {
@@ -110,7 +110,7 @@ int disp_favorite(nt_window_tp wp,
 		}
 		break;
 	case NT_KEY_REFRESH:
-		return DISP_STATE_REFRESH; 
+		return DISP_CMD_REFRESH; 
 	case NT_KEY_COMMAND1:
 		assert(wp->cmd_param);
 		cmd = parse_cmd1(wp->cmd_param);
@@ -121,6 +121,8 @@ int disp_favorite(nt_window_tp wp,
 			return DISP_CMD_UPLOAD_BOARDS;
 		case NT_CMD_UPLOAD_THREADS:
 			return DISP_CMD_UPLOAD_THREADS;
+		case NT_CMD_DISP_HISTORY:
+			return DISP_STATE_HISTORY;
 		}
 		break;
 	case NT_KEY_CLOSE:
@@ -212,7 +214,7 @@ int disp_favorite(nt_window_tp wp,
 						(*h_sel_threadp) = nt_searched_thread_alloc(
 							board_name, NULL, NULL);
 						if((*h_sel_threadp))
-							result_state |= DISP_CMD_SEL_FAVORITE_BOARD;
+							result_state |= DISP_CMD_SEL_BOARD;
 					}
 				}else{
 					attr = 0;
@@ -265,12 +267,12 @@ int disp_favorite(nt_window_tp wp,
 						(*h_sel_threadp) = nt_searched_thread_alloc(
 							board_name, dat_name, title);
 						if((*h_sel_threadp))
-							result_state |= DISP_CMD_SEL_FAVORITE_THREAD;
+							result_state |= DISP_CMD_SEL_THREAD;
 					}else if(sel_flag2){
 						(*h_sel_threadp) = nt_searched_thread_alloc(
 							board_name, NULL, NULL);
 						if((*h_sel_threadp))
-							result_state |= DISP_CMD_SEL_FAVORITE_BOARD;
+							result_state |= DISP_CMD_SEL_BOARD;
 					}
 				}else{
 					attr = 0;
@@ -468,6 +470,11 @@ static int parse_cmd1(const char *param)
 	if(0 == strncmp(NT_COMMAND1_UPLOAD_1,param,
 			strlen(NT_COMMAND1_UPLOAD_1))){
 		offset = strlen(NT_COMMAND1_UPLOAD_1);
+	}else if((0 == strncmp(NT_COMMAND1_HISTORY_1,param,
+			strlen(NT_COMMAND1_HISTORY_1))) ||
+			(0 == strncmp(NT_COMMAND1_HISTORY_2,param,
+			strlen(NT_COMMAND1_HISTORY_2)))){
+		return NT_CMD_DISP_HISTORY;
 	}else{
 		return NT_CMD_NONE;
 	}
@@ -485,6 +492,7 @@ static int parse_cmd1(const char *param)
 		0 == strncmp(start, NT_COMMAND1_UPLOAD_THREAD2,len)){
 		return NT_CMD_UPLOAD_THREADS;
 	}
+	
 	return NT_CMD_ERR;
 }
 
