@@ -41,7 +41,8 @@
 #define NT_CMD_ID 4
 #define NT_CMD_SEARCH_THREAD 5
 #define NT_CMD_FAVORITE 6
-#define NT_CMD_AUTO_SCROLL 7
+#define NT_CMD_HISTORY 7
+#define NT_CMD_AUTO_SCROLL 8
 
 #define AUTO_SCROLL_NONE 0
 #define AUTO_SCROLL_UP  -1
@@ -241,7 +242,9 @@ int disp_reslist(nt_window_tp wp, int prev_state, nt_2ch_selected_item_handle h_
 		}
 		break;
 	case NT_KEY_REFRESH:
-		return DISP_STATE_REFRESH; 
+		return DISP_CMD_REFRESH; 
+	case NT_KEY_ERASE:
+		return DISP_STATE_THREADTITLE; 
 	case NT_KEY_CLOSE:
 	case KEY_LEFT:
 		return ctxp->prev_state; 
@@ -430,6 +433,8 @@ int disp_reslist(nt_window_tp wp, int prev_state, nt_2ch_selected_item_handle h_
 			return DISP_STATE_SEARCH_THREAD;
 		case NT_CMD_FAVORITE:
 			return DISP_STATE_FAVORITE;
+		case NT_CMD_HISTORY:
+			return DISP_STATE_HISTORY;
 		case NT_CMD_WRITE:
 			return DISP_STATE_EDITOR;
 		case NT_CMD_JMP_NEW:
@@ -920,6 +925,11 @@ static int parse_cmd1(const char *param, const char **end)
 		0 == strncmp(NT_COMMAND1_FAVORITE_2,param,
 			strlen(NT_COMMAND1_FAVORITE_2))){
 		return NT_CMD_FAVORITE;
+	}else if(0 == strncmp(NT_COMMAND1_HISTORY_1,param,
+			strlen(NT_COMMAND1_HISTORY_1)) ||
+		0 == strncmp(NT_COMMAND1_HISTORY_2,param,
+			strlen(NT_COMMAND1_HISTORY_2))){
+		return NT_CMD_HISTORY;
 	}else if(0 == strncmp(NT_COMMAND1_AUTOSCROLL_1,param,
 			strlen(NT_COMMAND1_AUTOSCROLL_1)) ||
 		0 == strncmp(NT_COMMAND1_AUTOSCROLL_2,param,
@@ -939,7 +949,8 @@ static ctx_reslist_tp init_context(nt_2ch_selected_item_handle h_select,
 	
 	board_name = nt_2ch_selected_item_get_board_name(h_select);
 	dat_name = nt_2ch_selected_item_get_thread_dat_name(h_select);
-	assert(board_name && dat_name);
+	assert(board_name);
+	assert(dat_name);
 
 	ctxp = (ctx_reslist_tp)calloc(1,sizeof(ctx_reslist_t));
 
