@@ -77,10 +77,6 @@ typedef struct tag_nt_favorite_thread_t {
 	int num_res;
 } nt_favorite_thread_t;
 
-static int local_wcscmp(void *lhs, void *rhs)
-{
-	return wcscmp((const wchar_t *)lhs, (const wchar_t *)rhs);
-}
 static void free_favorite_board(void *ptr);
 static void free_favorite_grp(void *ptr);
 static void free_grp_content(void *ptr);
@@ -1377,7 +1373,7 @@ nt_link_tp nt_favorite_get_update_board_list(
 				continue;
 			if(board_name_linkp){
 				cptr = (const wchar_t*)nt_link_find(
-						board_name_linkp, (void*)board_name, local_wcscmp);
+						board_name_linkp, (void*)board_name, nt_link_wcscmp_fnc);
 				if(cptr)
 					continue;
 			}
