@@ -84,12 +84,17 @@ static const char *NT_SQL_QUERY_BOARD_LAST_QUERY =
 	"SELECT date_time FROM usr_log WHERE rec_type = 1 "
 	"AND board_name = :board_name AND dat_name = 'query_time' ";
 
+static const char *NT_SQL_QUERY_USR_TABLE = 
+	"SELECT board_name, dat_name, res_no FROM usr_log "
+	"ORDER BY date_time DESC "
+	"LIMIT :limit OFFSET :offset ";
 
 static BOOL usr_tbl_create(sqlite3 *dbp);
 static int usr_tbl_validate(sqlite3 *dbp);
 
 static nt_usr_db_thread_data_tp
-	thread_data_alloc(int read_count, const wchar_t *dat_name);
+	thread_data_alloc(int read_count, 
+		const wchar_t *dat_name, const wchar_t *board_name);
 static BOOL nt_remove_thread_data(nt_link_tp *thread_data,
 		const wchar_t *dat_name);
 
@@ -271,7 +276,7 @@ nt_link_tp nt_usr_db_query_read_count_list(nt_usr_db_handle db_handle,
 					dat_nm_buf, sizeof(dat_nm_buf)))
 			goto ERROR_TRAP;
 		thread_datap =
-			thread_data_alloc(res_no, dat_nm_buf);
+			thread_data_alloc(res_no, dat_nm_buf, NULL);
 		if(!thread_datap)
 			goto ERROR_TRAP;
 		linkp = nt_link_add_data(result_linkp, thread_datap);
@@ -477,6 +482,7 @@ char* nt_usr_db_board_last_query(nt_usr_db_handle db_handle,
 	rc = sqlite3_step(stmt);
 	if(rc != SQLITE_DONE){
 		free(result);
+		result = NULL;
 		goto ERROR_TRAP;
 	}
 ERROR_TRAP:
@@ -611,6 +617,110 @@ ERROR_TRAP:
 	return result;
 }
 
+nt_link_tp nt_usr_db_query_usr_table(nt_usr_db_handle db_handle,
+	int offset, int limit)
+{
+	nt_link_tp result_linkp;
+	nt_link_tp linkp;
+	nt_usr_db_thread_data_tp thread_datap;
+	const unsigned char *dat_name, *board_name;
+	int res_no;
+	int rc , idx;
+	ctx_usr_db_tp ctxp;
+	wchar_t board_nm_buf[128];
+	wchar_t dat_nm_buf[64];
+	sqlite3_stmt *stmt;
+	iconv_t icd;
+	BOOL result;
+
+	assert(db_handle);
+	assert(db_handle->chk_sum == NT_USR_DB_CHK_SUM);
+
+	result_linkp = NULL;
+	stmt = NULL;
+	icd = (iconv_t)-1;
+	result = FALSE;
+
+	ctxp = (ctx_usr_db_tp)db_handle;
+
+	if(!nt_usr_db_open(db_handle)){
+		return NULL;
+	}
+
+	rc = sqlite3_prepare_v2(ctxp->dbp,
+			NT_SQL_QUERY_USR_TABLE, -1,
+			&stmt, NULL);
+	if(rc != SQLITE_OK){
+		fputs(sqlite3_errmsg(ctxp->dbp), stderr);
+		nt_usr_db_close(db_handle);
+		return NULL;
+	}
+	idx = sqlite3_bind_parameter_index(stmt, ":limit");
+	if(idx == 0 ||
+		SQLITE_OK != sqlite3_bind_int(stmt, idx, limit)){
+		goto ERROR_TRAP;
+	}
+	idx = sqlite3_bind_parameter_index(stmt, ":offset");
+	if(idx == 0 ||
+		SQLITE_OK != sqlite3_bind_int(stmt, idx, offset)){
+		goto ERROR_TRAP;
+	}
+
+	icd = iconv_open("wchar_t", "UTF-8");
+	if(icd == (iconv_t)-1){
+	    perror("e");
+		goto ERROR_TRAP;
+	}
+
+	while(SQLITE_ROW == (rc = sqlite3_step(stmt))){
+		res_no = sqlite3_column_int(stmt, 2);
+		if(res_no <= 0)
+			continue;
+		dat_name = sqlite3_column_text(stmt, 1);
+		if(dat_name == NULL)
+			goto ERROR_TRAP;
+		board_name = sqlite3_column_text(stmt, 0);
+		if(board_name == NULL)
+			goto ERROR_TRAP;
+		
+		if(!nt_conv_local2wc(icd, (char*)dat_name, 
+					dat_nm_buf, sizeof(dat_nm_buf)))
+			goto ERROR_TRAP;
+		if(!nt_conv_local2wc(icd, (char*)board_name, 
+					board_nm_buf, sizeof(board_nm_buf)))
+			goto ERROR_TRAP;
+		
+		thread_datap =
+			thread_data_alloc(res_no, dat_nm_buf, board_nm_buf);
+		if(!thread_datap)
+			goto ERROR_TRAP;
+		
+		linkp = nt_link_add_data(result_linkp, thread_datap);
+		if(!linkp){
+			nt_usr_db_thread_data_free(thread_datap);
+			goto ERROR_TRAP;
+		}
+		if(!result_linkp)
+			result_linkp = linkp;
+
+	}
+	if(SQLITE_DONE == rc){
+		result = TRUE;
+	}
+ERROR_TRAP:
+	if(icd != (iconv_t)-1)
+		iconv_close(icd);
+	if(stmt)
+		sqlite3_finalize(stmt);
+	nt_usr_db_close(db_handle);
+	if(!result && result_linkp){
+		nt_all_link_free(result_linkp, 
+				nt_usr_db_thread_data_free);
+		result_linkp = NULL;
+	}
+	return result_linkp;
+}
+
 static BOOL nt_remove_thread_data(nt_link_tp *threadpp,
 		const wchar_t *dat_name)
 {
@@ -708,7 +818,9 @@ static BOOL usr_tbl_create(sqlite3 *dbp)
 
 
 static nt_usr_db_thread_data_tp
-	thread_data_alloc(int read_count, const wchar_t *dat_name)
+	thread_data_alloc(int read_count, 
+			const wchar_t *dat_name,
+			const wchar_t *board_name)
 {
 	nt_usr_db_thread_data_tp datap;
 	wchar_t *wc;
@@ -725,6 +837,17 @@ static nt_usr_db_thread_data_tp
 		return NULL;
 	}
 	datap->dat_name = wc;
+	if(board_name){
+		wc = nt_w_str_clone(board_name);
+		if(!wc){
+			free(datap->dat_name);
+			free(datap);
+			return NULL;
+		}
+		datap->board_name = wc;
+	}else{
+		datap->board_name = NULL;
+	}
 	datap->read_count = read_count;
 	return datap;
 }
@@ -734,5 +857,7 @@ void nt_usr_db_thread_data_free(void *ptr)
 	nt_usr_db_thread_data_tp datap =
 		(nt_usr_db_thread_data_tp)ptr;
 	free(datap->dat_name);
+	if(datap->board_name)
+		free(datap->board_name);
 	free(ptr);
 }
